Module ups

Module ups 

Bindings to libups.h to work with UPS patches.

Enums

upserror

Functions

ups_apply
Applies the UPS patch in patch to in_ and stores it to out.
ups_create
Creates an UPS patch that converts source to target and stores it to patch.
ups_free
Frees the memory returned in the output parameters of the above.