Function ips_apply_study
Source pub unsafe extern "C" fn ips_apply_study(
patch: mem,
study: *mut ipsstudy,
in_: mem,
out: *mut mem,
) -> ipserror
Apply a patch using a previously made study to avoid recreating a study.
Since ips_apply calls ips_study
before applying the patch, you should use this function if you have already
created a study beforehand.