pub unsafe extern "C" fn ups_free(mem: mem)Expand description
Frees the memory returned in the output parameters of the above.
Do not call it twice on the same input, nor on anything you got from
anywhere else. ups_free is guaranteed to be equivalent to calling
free from <stdlib.h> on mem.ptr.